==> auto_flutter_dig-0.5.0.tar.gz: auto_flutter_dig-0.5.0/src/auto_flutter_dig/module/aflutter/task/project/init/gitignore.py <==
from ......model.error import E, SilentWarning
from ......model.task import *
from ......model.task.init.project_identity import InitProjectTaskIdentity
from ....identity import AflutterTaskIdentity

__all__ = ["ProjectInitGitIgnoreTask"]


class _ProjectInitGistIgnoreTaskIdentity(AflutterTaskIdentity, InitProjectTaskIdentity):
    ...


class ProjectInitGitIgnoreTask(Task):
    identity = _ProjectInitGistIgnoreTaskIdentity(
        "-project-init-git-ignore",
        "",
        [],
        lambda: ProjectInitGitIgnoreTask(),  # pylint: disable=unnecessary-lambda
    )

    def describe(self, args: Args) -> str:
        return "Configure .gitignore"

    def execute(self, args: Args) -> TaskResult:
        try:
            with open(".gitignore", "r+", encoding="utf-8") as file:
                found = False
                for line in file:
                    if not isinstance(line, str):
                        continue
                    line = line.strip("\n")
                    if line == "*.log" or line.startswith(("*.log ", "*.log#")):
                        found = True
                        break
                    if line == "aflutter.log" or line.startswith(("aflutter.log ", "aflutter.log#")):
                        found = True
                        break

                if found:
                    return TaskResult(args)

                file.writelines(("aflutter.log"))

        except BaseException as error:
            return TaskResult(
                args,
                error=E(SilentWarning(".gitignore can not be open")).caused_by(error),
                success=True,
            )

        return TaskResult(args)

==> auto_flutter_dig-0.6.1.tar.gz: auto_flutter_dig-0.6.1/src/auto_flutter_dig/module/aflutter/task/project/init/gitignore.py <==
from ......model.error import Err, SilentWarning
from ......model.task.task import *  # pylint: disable=wildcard-import
from ......model.task.init.project_identity import InitProjectTaskIdentity
from ......module.aflutter.identity import AflutterTaskIdentity

__all__ = ["ProjectInitGitIgnoreTask"]


class _ProjectInitGistIgnoreTaskIdentity(AflutterTaskIdentity, InitProjectTaskIdentity):
    ...


class ProjectInitGitIgnoreTask(Task):
    identity = _ProjectInitGistIgnoreTaskIdentity(
        "-project-init-git-ignore",
        "",
        [],
        lambda: ProjectInitGitIgnoreTask(),  # pylint: disable=unnecessary-lambda
    )

    def describe(self, args: Args) -> str:
        return "Configure .gitignore"

    def execute(self, args: Args) -> TaskResult:
        try:
            with open(".gitignore", "r+", encoding="utf-8") as file:
                found = False
                for line in file:
                    if not isinstance(line, str):
                        continue
                    line = line.strip("\n")
                    if line == "*.log" or line.startswith(("*.log ", "*.log#")):
                        found = True
                        break
                    if line == "aflutter.log" or line.startswith(("aflutter.log ", "aflutter.log#")):
                        found = True
                        break

                if found:
                    return TaskResult(args)

                file.writelines(("aflutter.log"))

        except BaseException as error:
            return TaskResult(
                args,
                error=Err(SilentWarning(".gitignore can not be open"), error),
                success=True,
            )

        return TaskResult(args)
